aboutsummaryrefslogtreecommitdiff
path: root/lib/utils_base.c
diff options
context:
space:
mode:
authorGravatar Thomas Guyot-Sionnest <dermoth@aei.ca> 2014-01-27 08:35:23 -0500
committerGravatar Thomas Guyot-Sionnest <dermoth@aei.ca> 2014-01-27 08:35:23 -0500
commit189e2aa344b28a2cb5b5783450de201a9b2e3110 (patch)
treed67c6b5a7e591dfd90d57d3ca7f660ac4d0fcfbe /lib/utils_base.c
parent4a10a9493acaf1f12da12ef4881e2abacec1373a (diff)
downloadmonitoring-plugins-189e2aa344b28a2cb5b5783450de201a9b2e3110.tar.gz
Rename MP_STATE_DIRECTORY to MP_STATE_PATH
Diffstat (limited to 'lib/utils_base.c')
-rw-r--r--lib/utils_base.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/utils_base.c b/lib/utils_base.c
index fdd7d23c..f5f75067 100644
--- a/lib/utils_base.c
+++ b/lib/utils_base.c
@@ -417,10 +417,10 @@ void _cleanup_state_data() {
char* _np_state_calculate_location_prefix(){
char *env_dir;
/* Do not allow passing MP_STATE_DIRECTORY in setuid plugins
* for security reasons */
if (mp_suid() == FALSE) {
- env_dir = getenv("MP_STATE_DIRECTORY");
+ env_dir = getenv("MP_STATE_PATH");
if(env_dir && env_dir[0] != '\0')
return env_dir;
/* This is the former ENV, for backward-compatibility */
@@ -417,10 +417,10 @@ void _cleanup_state_data() {
char* _np_state_calculate_location_prefix(){
char *env_dir;
- /* Do not allow passing MP_STATE_DIRECTORY in setuid plugins
+ /* Do not allow passing MP_STATE_PATH in setuid plugins
* for security reasons */
if (mp_suid() == FALSE) {